# resurfaceio-logger-python
&copy; 2016-2019 Resurface Labs Inc.

Logging usage of Python cloud apps, with user privacy by design.

## Contents

<ul>
<li><a href="#dependencies">Dependencies</a></li>
<li><a href="#installing_with_pip">Installing With pip</a></li>
<li><a href="#logging_from_django">Logging From Django</a></li>
<li><a href="#logging_with_api">Logging With API</a></li>
<li><a href="#privacy">Protecting User Privacy</a></li>
</ul>

<a name="dependencies"></a>

## Dependencies

Requires Python 3.x. No other dependencies to conflict with your app.

<a name="installing_with_pip"></a>

## Installing With pip

```
pip install --upgrade usagelogger
```

<a name="logging_from_django"></a>

## Logging From Django

<a name="logging_with_api"></a>

## Logging With API

Loggers can be directly integrated into your application using our [API](API.md). This requires the most effort compared with
the options described above, but also offers the greatest flexibility and control.

[API documentation](API.md)

<a name="privacy"></a>

## Protecting User Privacy

Loggers always have an active set of <a href="https://resurface.io/rules.html">rules</a> that control what data is logged
and how sensitive data is masked. All of the examples above apply a predefined set of rules (`include strict`),
but logging rules are easily customized to meet the needs of any application.

<a href="https://resurface.io/rules.html">Logging rules documentation</a>
